@@ -155,6 +155,37 @@ VISIBILITY_UNOBSCURED     = 0
 VISIBILITY_PARTIAL        = 1
 VISIBILITY_FULLY_OBSCURED = 2
 
+# GdkFunction's
+COPY   = 0
+INVERT = 1
+XOR    = 2
+
+# GdkFill's
+SOLID           = 0
+TILED           = 1
+STIPPLED        = 2
+OPAQUE_STIPPLED = 3
+
+# GdkFillRule's
+EVEN_ODD_RULE = 0
+WINGDING_RULE = 1
+
+# GdkLineStyle's
+LINE_SOLID       = 0
+LINE_ON_OFF_DASH = 1
+LINE_DOUBLE_DASH = 2
+
+# GdkCapStyle's
+CAP_NOT_LAST   = 0
+CAP_BUTT       = 1
+CAP_ROUND      = 2
+CAP_PROJECTING = 3
+
+# GdkJoinStyle's
+JOIN_MITER = 0
+JOIN_ROUND = 1
+JOIN_BEVEL = 2
+
 # these are the Key Symbols for GDK
 # they were created with sed -n 's/#define GDK)\([^ ]*\)/\1 =/p' <gdkkeysyms.h
 VoidSymbol = 0xFFFFFF
