@@ -29,7 +29,6 @@ if '--display' in _sys.argv or _os.environ.has_key('DISPLAY'):
 	_gtk.gtk_init()
 else:
 	print 'No display information -- gtk_init not called'
-_gtk.gtk_rc_init()
 
 class GtkObject:
 	def __init__(self, _obj=None):
@@ -95,6 +94,13 @@ class GtkObject:
 		_gtk.gtk_signal_handler_unblock(self._o, id)
 	def signal_handlers_destroy(self):
 		_gtk.gtk_signal_handlers_destroy(self._o)
+	def emit(self, signal, *args):
+		params = []
+		for i in args:
+			if hasattr(i, '_o'): params.append(i._o)
+			elif hasattr(i, '_at'): params.append(i._at)
+			else: params.append(i)
+		return _gtk.gtk_signal_emitv_by_name(self._o, signal, params)
 	def emit_stop_by_name(self, sig):
 		_gtk.gtk_signal_emit_stop_by_name(self._o, sig)
 
@@ -762,6 +768,14 @@ class GtkCList(GtkContainer):
 			self._o = _gtk.gtk_clist_new(cols)
 		else:
 			self._o = _gtk.gtk_clist_new_with_titles(cols, titles)
+	def __getattr__(self, attr):
+		attrs = {
+			'selection':_gtk.gtk_clist_get_selection,
+		}
+		if attrs.has_key(attr):
+			return attrs[attr](self._o)
+		else:
+			raise AttributeError, attr
 	def append(self, values):
 		return _gtk.gtk_clist_append(self._o, values)
 	def clear(self, obj=None):
@@ -792,6 +806,8 @@ class GtkCList(GtkContainer):
 		return _gtk.gtk_clist_get_pixmap(self._o, r, c)
 	def get_pixtext(self, r, c):
 		return _gtk.gtk_clist_get_pixtext(self._o, r, c)
+	def get_selection_info(self, x, y):
+		return _gtk.gtk_clist_get_selection_info(self._o, x, y)
 	def insert(self, row, values):
 		_gtk.gtk_clist_insert(self._o, row, values)
 	def moveto(self, row=-1, col=-1, row_align=0.5, col_align=0.5):
@@ -1495,7 +1511,7 @@ del m
 
 class GtkAcceleratorTable:
 	def __init__(self, _obj=None):
-		if _obj: self._o = _obj; return
+		if _obj: self._at = _obj; return
 		self._at = _gtk.gtk_accelerator_table_new()
 	def install(self, obj, signame, acc_key, acc_mods):
 		_gtk.gtk_accelerator_table_install(self._at, obj._o, signame,
@@ -1597,6 +1613,12 @@ def load_fontset(fontset):
 
 # colour allocation
 def colour_alloc(parent, red, green=None, blue=None):
+	if hasattr(parent, '_o'): cmap = parent.get_window().colormap
+	elif hasattr(parent, 'colormap'): cmap = parent.colormap
+	else: cmap = parent
+	if type(red) == type(''):
+		return cmap.alloc(red)
+	# red assumed to be an int
 	if green == None and blue == None:
 		green, blue = divmod(red, 256)
 		red, green  = divmod(green, 256)
@@ -1605,8 +1627,7 @@ def colour_alloc(parent, red, green=None, blue=None):
 		red   = (red   + 1) * 256 - 1
 		green = (green + 1) * 256 - 1
 		blue  = (blue  + 1) * 256 - 1
-	if hasattr(parent, '_o'): parent = parent._o
-	return _gtk.gdk_color_alloc(parent, red, green, blue)
+	return cmap.alloc(red, green, blue)
 # This one's for the Americans...
 color_alloc = colour_alloc
 
